Stan Math Library: stan::VectorBuilderHelper< T1, true, true > Class Template Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Types | Public Member Functions | List of all members
stan::VectorBuilderHelper< T1, true, true > Class Template Reference

Template specialization for using a vector. More...

`#include <VectorBuilderHelper.hpp>`

## Public Types
typedef std::vector< T1 > | type

## Public Member Functions
| VectorBuilderHelper (size_t n)
T1 & | operator[] (size_t i)
type & | data ()

## Detailed Description

### template<typename T1>
class stan::VectorBuilderHelper< T1, true, true >

Template specialization for using a vector.

Definition at line 14 of file VectorBuilderHelper.hpp.

## Member Typedef Documentation

template<typename T1 >

typedef std::vector<T1> stan::VectorBuilderHelper< T1, true, true >::type

Definition at line 20 of file VectorBuilderHelper.hpp.

## Constructor & Destructor Documentation

template<typename T1 >

stan::VectorBuilderHelper< T1, true, true >::VectorBuilderHelper | ( | size_t | n | ) |
| inlineexplicit

Definition at line 18 of file VectorBuilderHelper.hpp.

## Member Function Documentation

template<typename T1 >

type& stan::VectorBuilderHelper< T1, true, true >::data | ( |  | ) |
| inline

Definition at line 26 of file VectorBuilderHelper.hpp.

template<typename T1 >

T1& stan::VectorBuilderHelper< T1, true, true >::operator[] | ( | size_t | i | ) |
| inline

Definition at line 22 of file VectorBuilderHelper.hpp.

The documentation for this class was generated from the following file:

- stan/math/prim/arr/meta/VectorBuilderHelper.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.